==> ejc-ztpcdc-impl-3.0.0-20230802.031119-153-sources.jar: com/ejianc/business/dc/vo/DcLssueAddressBookDetailVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 签发通讯录-明细
 * 
 * @author generator
 * 
 */
public class DcLssueAddressBookDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long addressBookId; // 签发通讯录ID
    private String receiveDeptName; // 接收人部门名称
    private Long receiveUserId; // 接收人员id
    private String receiveUserCode; // 接收人编号
    private String receiveUserName; // 接收人姓名
    private Integer num; // 份数
    private Long transactorType; // 主办/协办--字典lssue_address_book_detail_zxb
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态

    public Long getAddressBookId() {
        return addressBookId;
    }

    public void setAddressBookId(Long addressBookId) {
        this.addressBookId = addressBookId;
    }

    public String getReceiveDeptName() {
        return receiveDeptName;
    }

    public void setReceiveDeptName(String receiveDeptName) {
        this.receiveDeptName = receiveDeptName;
    }
    public Long getReceiveUserId() {
        return receiveUserId;
    }

    public void setReceiveUserId(Long receiveUserId) {
        this.receiveUserId = receiveUserId;
    }
    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getTransactorType() {
        return transactorType;
    }

    @ReferDeserialTransfer
    public void setTransactorType(Long transactorType) {
        this.transactorType = transactorType;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-ztpcdc-impl-3.0.0-20231221.004858-259-sources.jar: com/ejianc/business/dc/vo/DcLssueAddressBookDetailVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 签发通讯录-明细
 * 
 * @author generator
 * 
 */
public class DcLssueAddressBookDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long addressBookId; // 签发通讯录ID
    private String receiveDeptName; // 接收人部门名称
    private Long receiveUserId; // 接收人员id
    private String receiveUserCode; // 接收人编号
    private String receiveUserName; // 接收人姓名
    private Integer num; // 份数
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态
    private String hostFlag; // 主办/协办（Y为主办，N为协办）

    public Long getAddressBookId() {
        return addressBookId;
    }

    public void setAddressBookId(Long addressBookId) {
        this.addressBookId = addressBookId;
    }

    public String getReceiveDeptName() {
        return receiveDeptName;
    }

    public void setReceiveDeptName(String receiveDeptName) {
        this.receiveDeptName = receiveDeptName;
    }
    public Long getReceiveUserId() {
        return receiveUserId;
    }

    public void setReceiveUserId(Long receiveUserId) {
        this.receiveUserId = receiveUserId;
    }
    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getHostFlag() {
        return hostFlag;
    }

    public void setHostFlag(String hostFlag) {
        this.hostFlag = hostFlag;
    }
}
